<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Twig;

use Dedi\Contracts\SyliusPluginSettings\SettingsProviderInterface;
use Dedi\SyliusStockHistoryPlugin\DependencyInjection\Settings\SettingsInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;
use Webmozart\Assert\Assert;

class SettingsCheckerExtension extends AbstractExtension
{
    public function __construct(private readonly SettingsProviderInterface $settingsProvider)
    {
    }

    public function getFunctions(): array
    {
        return [
            new TwigFunction('dedi_sylius_stock_history_check', [$this, 'check']),
            new TwigFunction('dedi_sylius_stock_history_is_enabled', [$this, 'isEnabled']),
            new TwigFunction('dedi_sylius_stock_history_is_admin_enabled', [$this, 'isAdminEnabled']),
        ];
    }

    public function check(string $setting): mixed
    {
        $settings = $this->settingsProvider->provide();

        Assert::isInstanceOf($settings, SettingsInterface::class);

        switch ($setting) {
            case 'enabled':
                return $settings->isEnabled();
            case 'admin_enabled':
                return $settings->isAdminEnabled();
            default:
                throw new \InvalidArgumentException(sprintf('Unrecognized Dedi Stock History Plugin setting %s', $setting));
        }
    }

    public function isEnabled(): bool
    {
        return (bool) $this->check('enabled');
    }

    public function isAdminEnabled(): bool
    {
        return (bool) $this->check('admin_enabled');
    }
}
